@@ -1,11 +1,11 @@
-# @(#)$Id: Functions.pm 223 2012-10-31 01:24:47Z pjf $
+# @(#)$Id: Functions.pm 235 2012-11-13 20:51:23Z pjf $
 
 package Class::Usul::Functions;
 
 use strict;
 use warnings;
 use feature      qw(state);
-use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 223 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 235 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Data::Printer alias => q(Dumper), colored => 1, indent => 3,
@@ -31,10 +31,11 @@ BEGIN {
                       env_prefix escape_TT exception find_source fold
                       hex2str home2appldir is_arrayref is_coderef
                       is_hashref is_member merge_attributes my_prefix
-                      prefix2class product say split_on__ squeeze
-                      strip_leader sub_name sum thread_id throw trim
-                      unescape_TT untaint_cmdline untaint_identifier
-                      untaint_path untaint_string zip) );
+                      prefix2class product say split_on__
+                      split_on_dash squeeze strip_leader sub_name sum
+                      thread_id throw trim unescape_TT untaint_cmdline
+                      untaint_identifier untaint_path untaint_string
+                      zip) );
 }
 
 use Sub::Exporter -setup => {
@@ -224,7 +225,9 @@ sub product (;@) {
 }
 
 sub say (;@) {
-   my @rest = @_; openhandle *STDOUT or return; chomp( @rest );
+   my @rest = @_; openhandle *STDOUT or return;
+
+   $rest[ 0 ] ||= q(); chomp( @rest );
 
    local ($OFS, $ORS) = $OSNAME eq EVIL ? ("\r\n", "\r\n") : ("\n", "\n");
 
@@ -236,6 +239,10 @@ sub split_on__ (;$$) {
    return (split m{ _ }mx, $_[ 0 ] || q())[ $_[ 1 ] || 0 ];
 }
 
+sub split_on_dash (;$$) {
+   return (split m{ \- }mx, $_[ 0 ] || q())[ $_[ 1 ] || 0 ];
+}
+
 sub squeeze (;$) {
    (my $y = $_[ 0 ] || q()) =~ s{ \s+ }{ }gmx; return $y;
 }
@@ -441,7 +448,7 @@ CatalystX::Usul::Functions - Globally accessible functions
 
 =head1 Version
 
-0.6.$Revision: 223 $
+0.6.$Revision: 235 $
 
 =head1 Synopsis
 
@@ -693,6 +700,13 @@ and then have newlines appended. Throws on IO errors
 Splits string by _ (underscore) and returns the requested field. Defaults
 to field zero
 
+=head2 split_on_dash
+
+   $field = split_on_dash $string, $field_no;
+
+Splits string by - (dash) and returns the requested field. Defaults
+to field zero
+
 =head2 squeeze
 
    $string = squeeze $string_containing_muliple_spacesd);
